@@ -13,7 +13,7 @@ $ffi_prefix = 'wasmtime_caller_';
 $ffi->load_custom_type('::PtrObject' => 'wasmtime_caller_t' => __PACKAGE__);
 
 # ABSTRACT: Wasmtime caller interface
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 
 our @callers;
@@ -54,7 +54,7 @@ Wasm::Wasmtime::Caller - Wasmtime caller interface
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -79,7 +79,7 @@ version 0.18
  
  my $store = Wasm::Wasmtime::Store->new;
  my $instance = Wasm::Wasmtime::Instance->new(
-   Wasm::Wasmtime::Module->new($store, wat => q{
+   Wasm::Wasmtime::Module->new($store->engine, wat => q{
      (module
        (import "" "print_wasm_string" (func $print_wasm_string (param i32)))
        (func (export "run")
