@@ -11,7 +11,7 @@ require Wasm::Wasmtime::Table;
 require Wasm::Wasmtime::Memory;
 
 # ABSTRACT: Wasmtime extern class
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 
 $ffi_prefix = 'wasm_extern_';
@@ -68,7 +68,7 @@ Wasm::Wasmtime::Extern - Wasmtime extern class
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ version 0.18
  
  my $store = Wasm::Wasmtime::Store->new;
  my $instance = Wasm::Wasmtime::Instance->new(
-   Wasm::Wasmtime::Module->new($store, wat => q{
+   Wasm::Wasmtime::Module->new($store->engine, wat => q{
      (module
        (func (export "foo") (param i32 i32) (result i32)
          local.get 0
